==> medium-editor-4.7.0.tgz: package/spec/exploits.spec.js <==
/*global MediumEditor, describe, it, expect, afterEach,
    beforeEach, jasmine, tearDown */

describe('Exploits', function () {
    'use strict';

    beforeEach(function () {
        jasmine.clock().install();
        this.el = document.createElement('div');
        this.el.className = 'editor';
        this.el.id = 'paste-editor';
        this.el.innerHTML = 'hhh';
        document.body.appendChild(this.el);
    });

    afterEach(function () {
        tearDown(this.el);
        jasmine.clock().uninstall();
    });

    it('Should not execute javascript with disableReturn false', function () {
        var evt, range,
            editorEl = this.el,
            sel = window.getSelection(),
            editor = new MediumEditor('.editor', {
                delay: 200,
                disableReturn: false
            }),
            pasteHandler = editor.getExtensionByName('paste'),
            test = {
                source: 'img onerror handler',
                paste: '><img src="x" onerror="alert(\'xss\')">',
                output: '<span id="editor-inner">&gt;&lt;img src="x" onerror="alert(\'xss\')"&gt;</span>'
            };

        // mock event with clipboardData API
        // test requires creating a function, so can't loop or jslint balks
        evt = {
            preventDefault: function () {
                return;
            },
            clipboardData: {
                getData: function () {
                    // do we need to return different results for the different types? text/plain, text/html
                    return test.paste;
                }
            }
        };

        editorEl.innerHTML = '<span id="editor-inner">&nbsp</span>';

        range = document.createRange();
        range.selectNodeContents(editorEl.firstChild);
        sel.removeAllRanges();
        sel.addRange(range);

        pasteHandler.handlePaste(evt, editorEl);
        jasmine.clock().tick(100);
        expect(editorEl.innerHTML).toEqual(test.output);
    });

    it('Should not execute javascript with disableReturn true', function () {
        var evt, range,
            editorEl = this.el,
            sel = window.getSelection(),
            editor = new MediumEditor('.editor', {
                delay: 200,
                disableReturn: true
            }),
            pasteHandler = editor.getExtensionByName('paste'),
            test = {
                source: 'img onerror handler',
                paste: '><img src="x" onerror="alert(\'xss\')">',
                output: '<span id="editor-inner">&gt;&lt;img src="x" onerror="alert(\'xss\')"&gt;</span>'
            };

        // mock event with clipboardData API
        // test requires creating a function, so can't loop or jslint balks
        evt = {
            preventDefault: function () {
                return;
            },
            clipboardData: {
                getData: function () {
                    // do we need to return different results for the different types? text/plain, text/html
                    return test.paste;
                }
            }
        };

        editorEl.innerHTML = '<span id="editor-inner">&nbsp</span>';

        range = document.createRange();
        range.selectNodeContents(document.getElementById('editor-inner'));
        sel.removeAllRanges();
        sel.addRange(range);

        pasteHandler.handlePaste(evt, editorEl);
        jasmine.clock().tick(100);
        expect(editorEl.innerHTML).toEqual(test.output);
    });
});

==> medium-editor-4.12.12.tgz: package/spec/exploits.spec.js <==
/*global describe, it, expect, afterEach,
    beforeEach, jasmine, setupTestHelpers */

describe('Exploits', function () {
    'use strict';

    beforeEach(function () {
        setupTestHelpers.call(this);
        this.el = this.createElement('div', 'editor', 'hhh');
        this.el.id = 'paste-editor';
    });

    afterEach(function () {
        this.cleanupTest();
    });

    it('Should not execute javascript with disableReturn false', function () {
        var evt, range,
            editorEl = this.el,
            sel = window.getSelection(),
            editor = this.newMediumEditor('.editor', {
                delay: 200,
                disableReturn: false
            }),
            pasteHandler = editor.getExtensionByName('paste'),
            test = {
                source: 'img onerror handler',
                paste: '><img src="x" onerror="alert(\'xss\')">',
                output: '<span id="editor-inner">&gt;&lt;img src="x" onerror="alert(\'xss\')"&gt;</span>'
            };

        // mock event with clipboardData API
        // test requires creating a function, so can't loop or jslint balks
        evt = {
            preventDefault: function () {
                return;
            },
            clipboardData: {
                getData: function () {
                    // do we need to return different results for the different types? text/plain, text/html
                    return test.paste;
                }
            }
        };

        editorEl.innerHTML = '<span id="editor-inner">&nbsp</span>';

        range = document.createRange();
        range.selectNodeContents(editorEl.firstChild);
        sel.removeAllRanges();
        sel.addRange(range);

        pasteHandler.handlePaste(evt, editorEl);
        jasmine.clock().tick(100);
        expect(editorEl.innerHTML).toEqual(test.output);
    });

    it('Should not execute javascript with disableReturn true', function () {
        var evt, range,
            editorEl = this.el,
            sel = window.getSelection(),
            editor = this.newMediumEditor('.editor', {
                delay: 200,
                disableReturn: true
            }),
            pasteHandler = editor.getExtensionByName('paste'),
            test = {
                source: 'img onerror handler',
                paste: '><img src="x" onerror="alert(\'xss\')">',
                output: '<span id="editor-inner">&gt;&lt;img src="x" onerror="alert(\'xss\')"&gt;</span>'
            };

        // mock event with clipboardData API
        // test requires creating a function, so can't loop or jslint balks
        evt = {
            preventDefault: function () {
                return;
            },
            clipboardData: {
                getData: function () {
                    // do we need to return different results for the different types? text/plain, text/html
                    return test.paste;
                }
            }
        };

        editorEl.innerHTML = '<span id="editor-inner">&nbsp</span>';

        range = document.createRange();
        range.selectNodeContents(document.getElementById('editor-inner'));
        sel.removeAllRanges();
        sel.addRange(range);

        pasteHandler.handlePaste(evt, editorEl);
        jasmine.clock().tick(100);
        expect(editorEl.innerHTML).toEqual(test.output);
    });
});
